| plot2D | R Documentation |
This function visualizes the regions of the representative tree
of the output of the mrs function.
plot2D(
ans,
type = "prob",
data.points = "all",
background = "none",
group = 1,
dim = c(1, 2),
levels = sort(unique(ans$RepresentativeTree$Levels)),
regions = rep(1, length(ans$RepresentativeTree$Levels)),
legend = FALSE,
main = "default",
abs = TRUE
)
ans |
An |
type |
Different options on how to visualize the rectangular regions.
The options are |
data.points |
Different options on how to plot the data points.
The options are |
background |
Different options on the background.
The options are |
group |
If |
dim |
If the data are multivariate,
|
levels |
Vector with the level of the regions to plot. The default is to plot regions at all levels. |
regions |
Binary vector indicating the regions to plot. The default is to plot all regions. |
legend |
Color legend for type. Default is |
main |
Overall title for the legend. |
abs |
If |
Invisibly returns NULL. The function is called for its side
effect of drawing one panel for each selected tree level on the current
graphics device. Rectangles encode posterior probabilities or effect sizes;
optional points and a smoothed background show the observed data.
Soriano J. and Ma L. (2017). Probabilistic multi-resolution scanning for two-sample differences. Journal of the Royal Statistical Society: Series B (Statistical Methodology). \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/rssb.12180")}
Ma L. and Soriano J. (2018). Analysis of distributional variation through multi-scale Beta-Binomial modeling. Journal of Computational and Graphical Statistics, 27(3), 529–541. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2017.1402774")}
set.seed(12345)
p = 2
n1 = 200
n2 = 200
mu1 = matrix( c(9,9,0,4,-2,-10,3,6,6,-10), nrow = 5, byrow=TRUE)
mu2 = mu1; mu2[2,] = mu1[2,] + 1
Z1 = sample(5, n1, replace=TRUE)
Z2 = sample(5, n2, replace=TRUE)
X1 = mu1[Z1,] + matrix(rnorm(n1*p), ncol=p)
X2 = mu2[Z2,] + matrix(rnorm(n2*p), ncol=p)
X = rbind(X1, X2)
colnames(X) = c(1,2)
G = c(rep(1, n1), rep(2,n2))
ans = mrs(X, G, K=8)
plot2D(ans, type = "prob", legend = TRUE)
plot2D(ans, type="empty", data.points = "differential",
background = "none")
plot2D(ans, type="none", data.points = "differential",
background = "smeared", levels = 4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.