View source: R/print.summary.mrs.R
| print.summary.mrs | R Documentation |
This function prints a summary of the output of the mrs function.
It provides the marginal prior and posterior of the null and the top regions of the representative tree.
## S3 method for class 'summary.mrs'
print(x, ...)
x |
A |
... |
Additional print parameters. |
Invisibly returns NULL. The method is called for its side
effect of printing the global prior and posterior null probabilities and,
when present, the selected differential regions with their posterior
alternative probabilities, effect sizes, region bounds, and split
directions.
Soriano J. and Ma L. (2017). Probabilistic multi-resolution scanning for two-sample differences. Journal of the Royal Statistical Society: Series B (Statistical Methodology). \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/rssb.12180")}
Ma L. and Soriano J. (2018). Analysis of distributional variation through multi-scale Beta-Binomial modeling. Journal of Computational and Graphical Statistics, 27(3), 529–541. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2017.1402774")}
set.seed(12345)
n = 100
p = 2
X = matrix(c(runif(p*n/2),rbeta(p*n/2, 1, 4)), nrow=n, byrow=TRUE)
G = c(rep(1,n/2), rep(2,n/2))
x = mrs(X=X, G=G)
fit = summary(x, rho = 0.95, abs_eff = 1)
print(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.