Learn R Programming

MRS (version 1.3.2)

print.summary.mrs: Print summary of a mrs object

Description

This function prints a summary of the output of the mrs function. It provides the marginal prior and posterior of the null and the top regions of the representative tree.

Usage

# S3 method for summary.mrs
print(x, ...)

Value

Invisibly returns NULL. The method is called for its side effect of printing the global prior and posterior null probabilities and, when present, the selected differential regions with their posterior alternative probabilities, effect sizes, region bounds, and split directions.

Arguments

x

A summary.mrs object

...

Additional print parameters.

References

Soriano J. and Ma L. (2017). Probabilistic multi-resolution scanning for two-sample differences. Journal of the Royal Statistical Society: Series B (Statistical Methodology). tools:::Rd_expr_doi("10.1111/rssb.12180")

Ma L. and Soriano J. (2018). Analysis of distributional variation through multi-scale Beta-Binomial modeling. Journal of Computational and Graphical Statistics, 27(3), 529--541. tools:::Rd_expr_doi("10.1080/10618600.2017.1402774")

Examples

Run this code
set.seed(12345)
n = 100
p = 2
X = matrix(c(runif(p*n/2),rbeta(p*n/2, 1, 4)), nrow=n, byrow=TRUE)
G = c(rep(1,n/2), rep(2,n/2))
x = mrs(X=X, G=G)
fit = summary(x, rho = 0.95, abs_eff = 1)
print(fit)

Run the code above in your browser using DataLab